import { defineComponent, ref, withDirectives, createVNode, resolveComponent, mergeProps, resolveDirective } from 'vue';
import { Select } from '@element-plus/icons-vue';

var cellEdit = defineComponent({
  name: "BcTableCellEdit",
  directives: {
    focus: {
      mounted: (el) => {
        el.querySelector("input").focus();
      }
    }
  },
  props: {
    modelValue: {
      type: [String, Number],
      default: ""
    },
    unit: {
      type: String,
      default: void 0
    }
  },
  emits: ["save", "blur"],
  setup(props, context) {
    const editing = ref(false);
    const cell = ref("");
    const inputRef = ref();
    function toggleEdit() {
      editing.value = !editing.value;
    }
    function save() {
      context.emit("save", cell.value);
      toggleEdit();
    }
    const editInput = () => withDirectives(createVNode(resolveComponent("bc-input"), mergeProps({
      "class": "bc-table-input",
      "ref": inputRef,
      "model-value": cell.value
    }, {
      "onUpdate:modelValue": (val) => {
        cell.value = val;
      },
      onFocus: () => {
        cell.value = props.modelValue;
      },
      onBlur: () => {
        editing.value && toggleEdit();
      },
      onKeyup: (e) => {
        e.code.includes("Enter") && save();
      }
    }), {
      suffix: () => createVNode(resolveComponent("el-icon"), {
        "class": "bc-table-input--operate",
        "color": "var(--el-color-success)",
        "onClick": save
      }, {
        default: () => [createVNode(Select, null, null)]
      })
    }), [[resolveDirective("focus")]]);
    const displayInput = () => createVNode("div", {
      "class": "bc-table-cell-edit",
      "onClick": toggleEdit
    }, [props.modelValue]);
    return () => editing.value ? editInput() : displayInput();
  }
});

export { cellEdit as default };
//# sourceMappingURL=cellEdit.mjs.map
