'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
var iconsVue = require('@element-plus/icons-vue');

var cellEdit = vue.defineComponent({
  name: "BcTableCellEdit",
  directives: {
    focus: {
      mounted: (el) => {
        el.querySelector("input").focus();
      }
    }
  },
  props: {
    modelValue: {
      type: [String, Number],
      default: ""
    },
    unit: {
      type: String,
      default: void 0
    }
  },
  emits: ["save", "blur"],
  setup(props, context) {
    const editing = vue.ref(false);
    const cell = vue.ref("");
    const inputRef = vue.ref();
    function toggleEdit() {
      editing.value = !editing.value;
    }
    function save() {
      context.emit("save", cell.value);
      toggleEdit();
    }
    const editInput = () => vue.withDirectives(vue.createVNode(vue.resolveComponent("bc-input"), vue.mergeProps({
      "class": "bc-table-input",
      "ref": inputRef,
      "model-value": cell.value
    }, {
      "onUpdate:modelValue": (val) => {
        cell.value = val;
      },
      onFocus: () => {
        cell.value = props.modelValue;
      },
      onBlur: () => {
        editing.value && toggleEdit();
      },
      onKeyup: (e) => {
        e.code.includes("Enter") && save();
      }
    }), {
      suffix: () => vue.createVNode(vue.resolveComponent("el-icon"), {
        "class": "bc-table-input--operate",
        "color": "var(--el-color-success)",
        "onClick": save
      }, {
        default: () => [vue.createVNode(iconsVue.Select, null, null)]
      })
    }), [[vue.resolveDirective("focus")]]);
    const displayInput = () => vue.createVNode("div", {
      "class": "bc-table-cell-edit",
      "onClick": toggleEdit
    }, [props.modelValue]);
    return () => editing.value ? editInput() : displayInput();
  }
});

exports["default"] = cellEdit;
//# sourceMappingURL=cellEdit.js.map
